package com.fuzamei.utils;

import java.io.File;
import java.io.IOException;
import java.util.HashSet;
import java.util.Set;

import org.springframework.web.multipart.MultipartFile;

import com.mchange.util.AssertException;

public final class FileTransferUtil {
	private static final String SP = File.separator;
	
	private FileTransferUtil(){
		throw new AssertException("instaniation is not permitted");
	}
	
	/**
	 * 完成上传文件的功能
	 * @param multipartFile	上传过来的文件对象
	 * @param modifiedFilename	被修改后的文件名并且是要被添加到文件夹路径后面的名字
	 * @param directoryPath	文件夹路径
	 */
	public static final void transfer(MultipartFile multipartFile, String modifiedFilename, String directoryPath){
		File dir = new File(directoryPath);
		if(!dir.isDirectory()){
			throw new RuntimeException("路径需要是文件夹路径");
		}
		if(!dir.exists()){
			dir.mkdirs();
		}
		String filePath = directoryPath + modifiedFilename;
		File newFile = new File(filePath);
		try {
			multipartFile.transferTo(newFile);
		} catch (Exception e) {
			if(newFile!=null){
				newFile.delete();
			}
			throw new RuntimeException("文件上传出现异常:"+e.getMessage());
		}
	}
	
	/**
	 * 
	 * @return 返回false说明没有重复的文件名，返回true说明有重复的文件名
	 */
	public static final boolean checkIfHasSameFileName(MultipartFile...files){
		int count = files.length;
		Set<String> set = new HashSet<>();
		for (MultipartFile file : files) {
			set.add(file.getOriginalFilename());
		}
		int identity = set.size();
		return identity==count?false:true;
	}
}
